# calibcant - tools for thermally calibrating AFM cantilevers
#
# Copyright (C) 2007,2008, William Trevor King
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# The author may be contacted at <wking@drexel.edu> on the Internet, or
# write to Trevor King, Drexel University, Physics Dept., 3141 Chestnut St.,
# Philadelphia PA 19104, USA.

import config

VERSION="0.2"

# handle extra verbose input modules, only imported if we need them
_flush_plot = None
_final_flush_plot = None
_pylab = None
def _dummy_fn(): pass

def _import_pylab() :
    """Import pylab plotting functions for when we need to plot.  This
    function can be called multiple times, and ensures that the pylab
    setup is only imported once.  It defines the functions
      _flush_plot() to be called after incremental changes,
      _final_flush_plot(), to be called at the end of any graphical processing, and
      _pylab, a reference to the pylab module."""
    global _pylab
    global _flush_plot
    global _final_flush_plot
    if _pylab == None :
        import pylab as _pylab
    if _flush_plot == None :
        if config.PYLAB_INTERACTIVE :
            _flush_plot = _pylab.draw
        else :
            _flush_plot = _pylab.show #_dummy_fn
    if _final_flush_plot == None :
        if config.PYLAB_INTERACTIVE :
            _final_flush_plot = _pylab.draw
        else :
            _final_flush_plot = _dummy_fn # _pylab.show

def write_array(ofile, array, seperator):
    """Erite an iterable array seperated by seperator.
    Terminate the output with an endline."""
    strings = [repr(x) for x in array]
    ofile.write(seperator.join(strings))
    ofile.write('\n')
